@@ -67,9 +67,11 @@ class Aviary(bullet_client.BulletClient):
         self.resetDebugVisualizerCamera(
             cameraDistance=5,
             cameraYaw=30,
-            cameraPitch=-45,
+            cameraPitch=-30,
             cameraTargetPosition=[0, 0, 1],
         )
+        if not self.use_camera:
+            self.configureDebugVisualizer(p.COV_ENABLE_GUI,0)
 
         # define new RNG
         self.np_random = np.random.RandomState(seed=seed)
